@@ -3,6 +3,9 @@
 use strict;
 use warnings;
 
+our $VERSION = '3.005'; # VERSION
+my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+
 use PDF::Builder;
 
 unless (scalar @ARGV >= 3) {
