@@ -3,7 +3,8 @@
 use strict;
 use warnings;
 
-# VERSION
+our $VERSION = '3.005'; # VERSION
+my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::File;
 
