@@ -68,6 +68,10 @@
 #
 use strict;
 use warnings;
+
+our $VERSION = '3.005'; # VERSION
+my $LAST_UPDATE = '3.002'; # manually update whenever code is changed
+
 use PDF::Builder;
 use PDF::Builder::Util;
 use Getopt::Long;
