@@ -5,6 +5,10 @@
 
 use warnings;
 use strict;
+
+our $VERSION = '3.005'; # VERSION
+my $LAST_UPDATE = '3.003'; # manually update whenever code is changed
+
 use Math::Trig;
 use List::Util qw(min max);
 
