@@ -5,8 +5,8 @@ use base 'PDF::Builder::Basic::PDF::Dict';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-# VERSION
-my $LATEST_UPDATE = '3.004'; # manually update whenever code is changed
+our $VERSION = '3.005'; # VERSION
+my $LAST_UPDATE = '3.005'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Util;
